# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class UsersOfferInformationApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_offer_events(self, **kwargs):  # noqa: E501
        """Get events about the seller's offers  # noqa: E501

        Use this endpoint to get events concerning changes in the authorized seller's offers. At present we support the following events:   - OFFER_ACTIVATED - offer is visible on site and available for purchase, occurs when offer status changes from ACTIVATING to ACTIVE.   - OFFER_CHANGED - occurs when offer's fields has been changed e.g. description or photos.   - OFFER_ENDED - offer is no longer available for purchase, occurs when offer status changes from ACTIVE to ENDED.   - OFFER_STOCK_CHANGED - stock in an offer was changed either via purchase or by seller.   - OFFER_PRICE_CHANGED - occurs when price in an offer was changed.   - OFFER_ARCHIVED - offer is no longer available on listing and has been archived.   - OFFER_BID_PLACED - bid was placed on the offer   - OFFER_BID_CANCELED - bid for offer was canceled  Returned events may occur by actions made via browser or API. The resource allows you to get events concerning active offers and offers scheduled for activation (status ACTIVE and ACTIVATING). Returned events do not concern offers in INACTIVE and ENDED status (the exception is OFFER_ARCHIVED event). Please note that one change may result in more than one event.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_offer_events(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str _from: The ID of the last seen event. Events that occured after the given event will be returned.
        :param int limit: The number of events that will be returned in the response.
        :param list[str] type: The types of events that will be returned in the response. All types of events are returned by default.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SellerOfferEventsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_offer_events_with_http_info(**kwargs)  # noqa: E501

    def get_offer_events_with_http_info(self, **kwargs):  # noqa: E501
        """Get events about the seller's offers  # noqa: E501

        Use this endpoint to get events concerning changes in the authorized seller's offers. At present we support the following events:   - OFFER_ACTIVATED - offer is visible on site and available for purchase, occurs when offer status changes from ACTIVATING to ACTIVE.   - OFFER_CHANGED - occurs when offer's fields has been changed e.g. description or photos.   - OFFER_ENDED - offer is no longer available for purchase, occurs when offer status changes from ACTIVE to ENDED.   - OFFER_STOCK_CHANGED - stock in an offer was changed either via purchase or by seller.   - OFFER_PRICE_CHANGED - occurs when price in an offer was changed.   - OFFER_ARCHIVED - offer is no longer available on listing and has been archived.   - OFFER_BID_PLACED - bid was placed on the offer   - OFFER_BID_CANCELED - bid for offer was canceled  Returned events may occur by actions made via browser or API. The resource allows you to get events concerning active offers and offers scheduled for activation (status ACTIVE and ACTIVATING). Returned events do not concern offers in INACTIVE and ENDED status (the exception is OFFER_ARCHIVED event). Please note that one change may result in more than one event.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_offer_events_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str _from: The ID of the last seen event. Events that occured after the given event will be returned.
        :param int limit: The number of events that will be returned in the response.
        :param list[str] type: The types of events that will be returned in the response. All types of events are returned by default.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SellerOfferEventsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['_from', 'limit', 'type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_offer_events" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and ('_from' in local_var_params and  # noqa: E501
                                                        len(local_var_params['_from']) > 256):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `_from` when calling `get_offer_events`, length must be less than or equal to `256`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 1000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_offer_events`, must be a value less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_offer_events`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in local_var_params and local_var_params['_from'] is not None:  # noqa: E501
            query_params.append(('from', local_var_params['_from']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'type' in local_var_params and local_var_params['type'] is not None:  # noqa: E501
            query_params.append(('type', local_var_params['type']))  # noqa: E501
            collection_formats['type'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offer-events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SellerOfferEventsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_offer_using_get(self, offer_id, **kwargs):  # noqa: E501
        """Get all fields of the particular offer  # noqa: E501

        Use this resource to retrieve all fields of the particular offer. <a href=\"../../sale/#similar-offer\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_offer_using_get(offer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: Offer identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Offer
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_offer_using_get_with_http_info(offer_id, **kwargs)  # noqa: E501

    def get_offer_using_get_with_http_info(self, offer_id, **kwargs):  # noqa: E501
        """Get all fields of the particular offer  # noqa: E501

        Use this resource to retrieve all fields of the particular offer. <a href=\"../../sale/#similar-offer\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_offer_using_get_with_http_info(offer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: Offer identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Offer, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['offer_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_offer_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'offer_id' is set
        if self.api_client.client_side_validation and ('offer_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['offer_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `offer_id` when calling `get_offer_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'offer_id' in local_var_params:
            path_params['offerId'] = local_var_params['offer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offers/{offerId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Offer',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search_offers_using_get(self, **kwargs):  # noqa: E501
        """Get seller's offers  # noqa: E501

        Use this resource to get the list of the seller's offers. You can use different query parameters to filter the list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_offers_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: Offer ID.
        :param str name: The text to search in the offer title.
        :param float selling_mode_price_amount_gte: The lower threshold of price.
        :param float selling_mode_price_amount_lte: The upper threshold of price.
        :param list[str] publication_status: The publication status of the offer. Passing more than one value will search for offers with any of the given statuses. By default all statuses are included. Example: `publication.status=INACTIVE&publication.status=ACTIVE` - returns offers with status `INACTIVE` or `ACTIVE`.
        :param list[str] selling_mode_format: The offer's selling format. Passing more than one value will search for offers with any of the given formats. By default all formats are included. Example: `sellingMode.format=BUY_NOW&sellingMode.format=ADVERTISEMENT` - returns offers with with format `BUY_NOW` or `ADVERTISEMENT`.
        :param list[str] external_id: The ID from the client's external system. Passing more than one value will search for offers with any of the given IDs. By default no ID is included. Example: `external.id=1233&external.id=1234` - returns offers with ID `1233` or `1234`. Single ID length shouldn't exceed 100 characters.
        :param str delivery_shipping_rates_id: The ID of shipping rates. Returns offers with given shipping rates ID.
        :param bool delivery_shipping_rates_id_empty: Allow to filter offers by existence of shipping rates ID.
        :param str sort: The results' sorting order. No prefix in the value means ascending order. `-` prefix means descending order. If you don't provide the sort parameter, the list is sorted by offer creation time, descending.
        :param int limit: The maximum number of offers returned in the response.
        :param int offset: Index of the first returned offer from all search results.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OffersSearchResultDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.search_offers_using_get_with_http_info(**kwargs)  # noqa: E501

    def search_offers_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get seller's offers  # noqa: E501

        Use this resource to get the list of the seller's offers. You can use different query parameters to filter the list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_offers_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: Offer ID.
        :param str name: The text to search in the offer title.
        :param float selling_mode_price_amount_gte: The lower threshold of price.
        :param float selling_mode_price_amount_lte: The upper threshold of price.
        :param list[str] publication_status: The publication status of the offer. Passing more than one value will search for offers with any of the given statuses. By default all statuses are included. Example: `publication.status=INACTIVE&publication.status=ACTIVE` - returns offers with status `INACTIVE` or `ACTIVE`.
        :param list[str] selling_mode_format: The offer's selling format. Passing more than one value will search for offers with any of the given formats. By default all formats are included. Example: `sellingMode.format=BUY_NOW&sellingMode.format=ADVERTISEMENT` - returns offers with with format `BUY_NOW` or `ADVERTISEMENT`.
        :param list[str] external_id: The ID from the client's external system. Passing more than one value will search for offers with any of the given IDs. By default no ID is included. Example: `external.id=1233&external.id=1234` - returns offers with ID `1233` or `1234`. Single ID length shouldn't exceed 100 characters.
        :param str delivery_shipping_rates_id: The ID of shipping rates. Returns offers with given shipping rates ID.
        :param bool delivery_shipping_rates_id_empty: Allow to filter offers by existence of shipping rates ID.
        :param str sort: The results' sorting order. No prefix in the value means ascending order. `-` prefix means descending order. If you don't provide the sort parameter, the list is sorted by offer creation time, descending.
        :param int limit: The maximum number of offers returned in the response.
        :param int offset: Index of the first returned offer from all search results.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OffersSearchResultDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['offer_id', 'name', 'selling_mode_price_amount_gte', 'selling_mode_price_amount_lte', 'publication_status', 'selling_mode_format', 'external_id', 'delivery_shipping_rates_id', 'delivery_shipping_rates_id_empty', 'sort', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_offers_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and ('external_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['external_id']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `external_id` when calling `search_offers_using_get`, number of items must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 1000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `search_offers_using_get`, must be a value less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `search_offers_using_get`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `search_offers_using_get`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offer_id' in local_var_params and local_var_params['offer_id'] is not None:  # noqa: E501
            query_params.append(('offer.id', local_var_params['offer_id']))  # noqa: E501
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'selling_mode_price_amount_gte' in local_var_params and local_var_params['selling_mode_price_amount_gte'] is not None:  # noqa: E501
            query_params.append(('sellingMode.price.amount.gte', local_var_params['selling_mode_price_amount_gte']))  # noqa: E501
        if 'selling_mode_price_amount_lte' in local_var_params and local_var_params['selling_mode_price_amount_lte'] is not None:  # noqa: E501
            query_params.append(('sellingMode.price.amount.lte', local_var_params['selling_mode_price_amount_lte']))  # noqa: E501
        if 'publication_status' in local_var_params and local_var_params['publication_status'] is not None:  # noqa: E501
            query_params.append(('publication.status', local_var_params['publication_status']))  # noqa: E501
            collection_formats['publication.status'] = 'multi'  # noqa: E501
        if 'selling_mode_format' in local_var_params and local_var_params['selling_mode_format'] is not None:  # noqa: E501
            query_params.append(('sellingMode.format', local_var_params['selling_mode_format']))  # noqa: E501
            collection_formats['sellingMode.format'] = 'multi'  # noqa: E501
        if 'external_id' in local_var_params and local_var_params['external_id'] is not None:  # noqa: E501
            query_params.append(('external.id', local_var_params['external_id']))  # noqa: E501
            collection_formats['external.id'] = 'multi'  # noqa: E501
        if 'delivery_shipping_rates_id' in local_var_params and local_var_params['delivery_shipping_rates_id'] is not None:  # noqa: E501
            query_params.append(('delivery.shippingRates.id', local_var_params['delivery_shipping_rates_id']))  # noqa: E501
        if 'delivery_shipping_rates_id_empty' in local_var_params and local_var_params['delivery_shipping_rates_id_empty'] is not None:  # noqa: E501
            query_params.append(('delivery.shippingRates.id.empty', local_var_params['delivery_shipping_rates_id_empty']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OffersSearchResultDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.pos import Pos  # noqa: E501
from allegro_api.rest import ApiException

class TestPos(unittest.TestCase):
    """Pos unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Pos
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.pos.Pos()  # noqa: E501
        if include_optional :
            return Pos(
                id = '0', 
                external_id = '0', 
                name = '0', 
                seller = allegro_api.models.seller.Seller(
                    id = '0', ), 
                type = '0', 
                address = allegro_api.models.address.Address(
                    street = '0', 
                    city = '0', 
                    zip_code = '0', 
                    state = '0', 
                    country_code = '0', 
                    coordinates = allegro_api.models.coordinates.Coordinates(
                        lat = 1.337, 
                        lon = 1.337, ), ), 
                phone_number = '0', 
                email = '0', 
                open_hours = [
                    allegro_api.models.open_hour.OpenHour(
                        day_of_week = '0', 
                        from = '0', 
                        to = '0', )
                    ], 
                service_time = '0', 
                payments = [
                    allegro_api.models.payment.Payment(
                        method = '0', )
                    ], 
                confirmation_type = '0', 
                status = '0', 
                created_at = '0', 
                updated_at = '0'
            )
        else :
            return Pos(
                name = '0',
                type = '0',
                address = allegro_api.models.address.Address(
                    street = '0', 
                    city = '0', 
                    zip_code = '0', 
                    state = '0', 
                    country_code = '0', 
                    coordinates = allegro_api.models.coordinates.Coordinates(
                        lat = 1.337, 
                        lon = 1.337, ), ),
                open_hours = [
                    allegro_api.models.open_hour.OpenHour(
                        day_of_week = '0', 
                        from = '0', 
                        to = '0', )
                    ],
                confirmation_type = '0',
                status = '0',
        )

    def testPos(self):
        """Test Pos"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.order_management_api import OrderManagementApi  # noqa: E501
from allegro_api.rest import ApiException


class TestOrderManagementApi(unittest.TestCase):
    """OrderManagementApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.order_management_api.OrderManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_order_shipments_using_post(self):
        """Test case for create_order_shipments_using_post

        Add a parcel tracking number  # noqa: E501
        """
        pass

    def test_find_mapping(self):
        """Test case for find_mapping

        Get mapping for line item id  # noqa: E501
        """
        pass

    def test_get_list_of_orders_using_get(self):
        """Test case for get_list_of_orders_using_get

        Get the user's orders  # noqa: E501
        """
        pass

    def test_get_order_events_statistics_using_get(self):
        """Test case for get_order_events_statistics_using_get

        Get order events statistics  # noqa: E501
        """
        pass

    def test_get_order_events_using_get(self):
        """Test case for get_order_events_using_get

        Get order events  # noqa: E501
        """
        pass

    def test_get_order_shipments_using_get(self):
        """Test case for get_order_shipments_using_get

        Get a list of parcel tracking numbers  # noqa: E501
        """
        pass

    def test_get_orders_details_using_get(self):
        """Test case for get_orders_details_using_get

        Get an order's details  # noqa: E501
        """
        pass

    def test_set_order_fulfillment_using_put(self):
        """Test case for set_order_fulfillment_using_put

        Set seller order status  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.offer import Offer  # noqa: E501
from allegro_api.rest import ApiException

class TestOffer(unittest.TestCase):
    """Offer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Offer
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.offer.Offer()  # noqa: E501
        if include_optional :
            return Offer(
                additional_services = allegro_api.models.just_id.JustId(
                    id = '0', ), 
                after_sales_services = allegro_api.models.after_sales_services.AfterSalesServices(
                    implied_warranty = allegro_api.models.implied_warranty.ImpliedWarranty(
                        id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                    return_policy = allegro_api.models.return_policy.ReturnPolicy(
                        id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                    warranty = allegro_api.models.warranty.Warranty(
                        id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), ), 
                attachments = [
                    allegro_api.models.attachment.Attachment(
                        id = '1928302_MANUAL_45d7a0f543e1b0d05e12a1aef5642efe63389a1d419fe9286d0f158044391fdce', )
                    ], 
                category = allegro_api.models.category.Category(
                    id = '0', ), 
                compatibility_list = allegro_api.models.compatibility_list.CompatibilityList(), 
                contact = allegro_api.models.just_id.JustId(
                    id = '0', ), 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                delivery = allegro_api.models.delivery.Delivery(
                    additional_info = '0', 
                    handling_time = 'PDT12H30M5S', 
                    shipment_date = '2018-04-01T08:00Z', 
                    shipping_rates = allegro_api.models.just_id.JustId(
                        id = '0', ), ), 
                description = allegro_api.models.standardized_description.StandardizedDescription(
                    sections = [
                        allegro_api.models.description_section.DescriptionSection(
                            items = [
                                allegro_api.models.description_section_item.DescriptionSectionItem(
                                    type = '0', )
                                ], )
                        ], ), 
                ean = '0', 
                external = allegro_api.models.external_id.ExternalId(
                    id = 'AH-129834', ), 
                id = '0', 
                images = [
                    allegro_api.models.image_url.ImageUrl(
                        url = '0', )
                    ], 
                location = allegro_api.models.location.Location(
                    city = '0', 
                    country_code = '0', 
                    post_code = '0', 
                    province = '0', ), 
                name = '0', 
                parameters = [
                    allegro_api.models.parameter.Parameter(
                        id = '0', 
                        range_value = allegro_api.models.parameter_range_value.ParameterRangeValue(
                            from = '0', 
                            to = '0', ), 
                        values = [
                            '0'
                            ], 
                        values_ids = [
                            '0'
                            ], )
                    ], 
                payments = allegro_api.models.payments.Payments(
                    invoice = '0', ), 
                product = allegro_api.models.just_id.JustId(
                    id = '0', ), 
                promotion = allegro_api.models.promotion.Promotion(
                    bold = True, 
                    department_page = True, 
                    emphasized = True, 
                    emphasized_highlight_bold_package = True, 
                    highlight = True, ), 
                publication = allegro_api.models.publication.Publication(
                    duration = 'PDT12H30M5S', 
                    ending_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    starting_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    status = 'INACTIVE', 
                    ended_by = 'USER', 
                    republish = False, ), 
                selling_mode = allegro_api.models.selling_mode.SellingMode(
                    format = 'BUY_NOW', 
                    price = null, 
                    minimal_price = null, 
                    starting_price = null, ), 
                size_table = allegro_api.models.just_id.JustId(
                    id = '0', ), 
                stock = allegro_api.models.stock.Stock(
                    available = 56, 
                    unit = '0', ), 
                tecdoc_specification = allegro_api.models.tecdoc_specification.TecdocSpecification(
                    id = '470b8513-b786-b7b9-9e7e-2f848729cfd6', 
                    items = [
                        allegro_api.models.tecdoc_specification_item.TecdocSpecificationItem(
                            name = 'Wersja TecDoc', 
                            values = ["0319"], )
                        ], ), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                validation = allegro_api.models.validation.Validation(
                    errors = [
                        allegro_api.models.validation_error.ValidationError(
                            code = '0', 
                            details = '0', 
                            message = '0', 
                            path = '0', 
                            user_message = '0', )
                        ], 
                    validated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else :
            return Offer(
                name = '0',
        )

    def testOffer(self):
        """Test Offer"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.categories_dto import CategoriesDto  # noqa: E501
from allegro_api.rest import ApiException

class TestCategoriesDto(unittest.TestCase):
    """CategoriesDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CategoriesDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.categories_dto.CategoriesDto()  # noqa: E501
        if include_optional :
            return CategoriesDto(
                categories = [
                    allegro_api.models.category_dto.CategoryDto(
                        id = '12', 
                        leaf = True, 
                        name = 'Pozostałe', 
                        options = allegro_api.models.category_options_dto.CategoryOptionsDto(
                            advertisement = True, 
                            advertisement_price_optional = True, 
                            variants_by_color_pattern_allowed = True, 
                            offers_with_product_publication_enabled = True, 
                            product_creation_enabled = True, 
                            product_ean_required = True, ), 
                        parent = allegro_api.models.category_dto_parent.CategoryDto_parent(
                            id = '709', ), )
                    ]
            )
        else :
            return CategoriesDto(
        )

    def testCategoriesDto(self):
        """Test CategoriesDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class AfterSalesServices(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'implied_warranty': 'ImpliedWarranty',
        'return_policy': 'ReturnPolicy',
        'warranty': 'Warranty'
    }

    attribute_map = {
        'implied_warranty': 'impliedWarranty',
        'return_policy': 'returnPolicy',
        'warranty': 'warranty'
    }

    def __init__(self, implied_warranty=None, return_policy=None, warranty=None, local_vars_configuration=None):  # noqa: E501
        """AfterSalesServices - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._implied_warranty = None
        self._return_policy = None
        self._warranty = None
        self.discriminator = None

        if implied_warranty is not None:
            self.implied_warranty = implied_warranty
        if return_policy is not None:
            self.return_policy = return_policy
        if warranty is not None:
            self.warranty = warranty

    @property
    def implied_warranty(self):
        """Gets the implied_warranty of this AfterSalesServices.  # noqa: E501


        :return: The implied_warranty of this AfterSalesServices.  # noqa: E501
        :rtype: ImpliedWarranty
        """
        return self._implied_warranty

    @implied_warranty.setter
    def implied_warranty(self, implied_warranty):
        """Sets the implied_warranty of this AfterSalesServices.


        :param implied_warranty: The implied_warranty of this AfterSalesServices.  # noqa: E501
        :type: ImpliedWarranty
        """

        self._implied_warranty = implied_warranty

    @property
    def return_policy(self):
        """Gets the return_policy of this AfterSalesServices.  # noqa: E501


        :return: The return_policy of this AfterSalesServices.  # noqa: E501
        :rtype: ReturnPolicy
        """
        return self._return_policy

    @return_policy.setter
    def return_policy(self, return_policy):
        """Sets the return_policy of this AfterSalesServices.


        :param return_policy: The return_policy of this AfterSalesServices.  # noqa: E501
        :type: ReturnPolicy
        """

        self._return_policy = return_policy

    @property
    def warranty(self):
        """Gets the warranty of this AfterSalesServices.  # noqa: E501


        :return: The warranty of this AfterSalesServices.  # noqa: E501
        :rtype: Warranty
        """
        return self._warranty

    @warranty.setter
    def warranty(self, warranty):
        """Sets the warranty of this AfterSalesServices.


        :param warranty: The warranty of this AfterSalesServices.  # noqa: E501
        :type: Warranty
        """

        self._warranty = warranty

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AfterSalesServices):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AfterSalesServices):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.pricing_api import PricingApi  # noqa: E501
from allegro_api.rest import ApiException


class TestPricingApi(unittest.TestCase):
    """PricingApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.pricing_api.PricingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_calculate_fee_preview_using_post(self):
        """Test case for calculate_fee_preview_using_post

        Calculate fee and commission for an offer  # noqa: E501
        """
        pass

    def test_offer_quotes_public_using_get(self):
        """Test case for offer_quotes_public_using_get

        Get the user's current offer quotes  # noqa: E501
        """
        pass

    def test_preview_fees_public_api_using_post(self):
        """Test case for preview_fees_public_api_using_post

        Preview offer fees  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.delivery_api import DeliveryApi  # noqa: E501
from allegro_api.rest import ApiException


class TestDeliveryApi(unittest.TestCase):
    """DeliveryApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.delivery_api.DeliveryApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_shipping_rates_set_using_post(self):
        """Test case for create_shipping_rates_set_using_post

        Create a new shipping rates set  # noqa: E501
        """
        pass

    def test_get_list_of_delivery_methods_using_get(self):
        """Test case for get_list_of_delivery_methods_using_get

        Get the list of delivery methods  # noqa: E501
        """
        pass

    def test_get_list_of_shipping_ratest_using_get(self):
        """Test case for get_list_of_shipping_ratest_using_get

        Get the user's shipping rates  # noqa: E501
        """
        pass

    def test_get_offer_shipping_rates_get(self):
        """Test case for get_offer_shipping_rates_get

        [BETA] Get shipping rates assigned to an offer  # noqa: E501
        """
        pass

    def test_get_sale_delivery_settings(self):
        """Test case for get_sale_delivery_settings

        Get the user's delivery settings  # noqa: E501
        """
        pass

    def test_get_shipping_rates_set_using_get(self):
        """Test case for get_shipping_rates_set_using_get

        Get the details of a shipping rates set  # noqa: E501
        """
        pass

    def test_modify_shipping_rates_set_using_put(self):
        """Test case for modify_shipping_rates_set_using_put

        Edit a user's shipping rates set  # noqa: E501
        """
        pass

    def test_put_sale_delivery_settings(self):
        """Test case for put_sale_delivery_settings

        Modify the user's delivery settings  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class PricingApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def calculate_fee_preview_using_post(self, public_offer_preview_request, **kwargs):  # noqa: E501
        """Calculate fee and commission for an offer  # noqa: E501

        Provides information about fee and commission for an offer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.calculate_fee_preview_using_post(public_offer_preview_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PublicOfferPreviewRequest public_offer_preview_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FeePreviewResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.calculate_fee_preview_using_post_with_http_info(public_offer_preview_request, **kwargs)  # noqa: E501

    def calculate_fee_preview_using_post_with_http_info(self, public_offer_preview_request, **kwargs):  # noqa: E501
        """Calculate fee and commission for an offer  # noqa: E501

        Provides information about fee and commission for an offer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.calculate_fee_preview_using_post_with_http_info(public_offer_preview_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PublicOfferPreviewRequest public_offer_preview_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FeePreviewResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['public_offer_preview_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method calculate_fee_preview_using_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'public_offer_preview_request' is set
        if self.api_client.client_side_validation and ('public_offer_preview_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['public_offer_preview_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `public_offer_preview_request` when calling `calculate_fee_preview_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'public_offer_preview_request' in local_var_params:
            body_params = local_var_params['public_offer_preview_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/pricing/offer-fee-preview', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FeePreviewResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def offer_quotes_public_using_get(self, offer_id, **kwargs):  # noqa: E501
        """Get the user's current offer quotes  # noqa: E501

        This endpoint returns current offer quotes (listing and promo fees) cycles for authenticated user and list of offers. <a href=\"../../news/2018-02-14-zasob_do_sprawdzania_daty_oplaty/\" target=\"_blank\">Read more</a>. <br/>2018-07-18 - resource update <a href=\"../../news/2018-07-18-aktualizacja_zasob_do_sprawdzania_daty_oplaty/\" target=\"_blank\">here</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.offer_quotes_public_using_get(offer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] offer_id: List of offer Ids, maximum 20 values. (required)
        :param str name: Offer quote name.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OfferQuotesDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.offer_quotes_public_using_get_with_http_info(offer_id, **kwargs)  # noqa: E501

    def offer_quotes_public_using_get_with_http_info(self, offer_id, **kwargs):  # noqa: E501
        """Get the user's current offer quotes  # noqa: E501

        This endpoint returns current offer quotes (listing and promo fees) cycles for authenticated user and list of offers. <a href=\"../../news/2018-02-14-zasob_do_sprawdzania_daty_oplaty/\" target=\"_blank\">Read more</a>. <br/>2018-07-18 - resource update <a href=\"../../news/2018-07-18-aktualizacja_zasob_do_sprawdzania_daty_oplaty/\" target=\"_blank\">here</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.offer_quotes_public_using_get_with_http_info(offer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] offer_id: List of offer Ids, maximum 20 values. (required)
        :param str name: Offer quote name.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OfferQuotesDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['offer_id', 'name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method offer_quotes_public_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'offer_id' is set
        if self.api_client.client_side_validation and ('offer_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['offer_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `offer_id` when calling `offer_quotes_public_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'offer_id' in local_var_params and local_var_params['offer_id'] is not None:  # noqa: E501
            query_params.append(('offer.id', local_var_params['offer_id']))  # noqa: E501
            collection_formats['offer.id'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/pricing/offer-quotes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OfferQuotesDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def preview_fees_public_api_using_post(self, wrapper_type_for_preview_conditions, **kwargs):  # noqa: E501
        """Preview offer fees  # noqa: E501

        This endpoint calculates fees for a provided offer conditions. The quotation is estimated and based on the current configuration of the Allegro price list and the data entered in this API. The stated price does not include package discounts. The rules of charging and amount of charges are described in the Allegro regulations in Appendix 4. The final amount of the fee for the offer will be available after approval under the tab: My Account> Accounts> History. <a href=\"../../news/2017-10-30-kalkulator_ogloszenia/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.preview_fees_public_api_using_post(wrapper_type_for_preview_conditions, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param WrapperTypeForPreviewConditions wrapper_type_for_preview_conditions: command (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WrapsListingAndCommissionsFees
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.preview_fees_public_api_using_post_with_http_info(wrapper_type_for_preview_conditions, **kwargs)  # noqa: E501

    def preview_fees_public_api_using_post_with_http_info(self, wrapper_type_for_preview_conditions, **kwargs):  # noqa: E501
        """Preview offer fees  # noqa: E501

        This endpoint calculates fees for a provided offer conditions. The quotation is estimated and based on the current configuration of the Allegro price list and the data entered in this API. The stated price does not include package discounts. The rules of charging and amount of charges are described in the Allegro regulations in Appendix 4. The final amount of the fee for the offer will be available after approval under the tab: My Account> Accounts> History. <a href=\"../../news/2017-10-30-kalkulator_ogloszenia/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.preview_fees_public_api_using_post_with_http_info(wrapper_type_for_preview_conditions, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param WrapperTypeForPreviewConditions wrapper_type_for_preview_conditions: command (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WrapsListingAndCommissionsFees, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['wrapper_type_for_preview_conditions']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method preview_fees_public_api_using_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'wrapper_type_for_preview_conditions' is set
        if self.api_client.client_side_validation and ('wrapper_type_for_preview_conditions' not in local_var_params or  # noqa: E501
                                                        local_var_params['wrapper_type_for_preview_conditions'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `wrapper_type_for_preview_conditions` when calling `preview_fees_public_api_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'wrapper_type_for_preview_conditions' in local_var_params:
            body_params = local_var_params['wrapper_type_for_preview_conditions']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/pricing/fee-preview', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WrapsListingAndCommissionsFees',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.images_and_attachments_api import ImagesAndAttachmentsApi  # noqa: E501
from allegro_api.rest import ApiException


class TestImagesAndAttachmentsApi(unittest.TestCase):
    """ImagesAndAttachmentsApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.images_and_attachments_api.ImagesAndAttachmentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_offer_attachment_using_post(self):
        """Test case for create_offer_attachment_using_post

        Create an offer attachment  # noqa: E501
        """
        pass

    def test_upload_offer_attachment_using_put(self):
        """Test case for upload_offer_attachment_using_put

        Upload an offer attachment  # noqa: E501
        """
        pass

    def test_upload_offer_image_using_post(self):
        """Test case for upload_offer_image_using_post

        Upload an offer image  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.seller_rebate_dto import SellerRebateDto  # noqa: E501
from allegro_api.rest import ApiException

class TestSellerRebateDto(unittest.TestCase):
    """SellerRebateDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SellerRebateDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.seller_rebate_dto.SellerRebateDto()  # noqa: E501
        if include_optional :
            return SellerRebateDto(
                benefits = [
                    allegro_api.models.benefit.Benefit(
                        specification = allegro_api.models.benefit_specification.BenefitSpecification(
                            type = '0', ), )
                    ], 
                created_at = '2019-05-01T10:12:32.321Z', 
                id = '7c9a76d3-9fd0-4d13-a4ce-5d49bec12c79', 
                offer_criteria = [
                    allegro_api.models.seller_rebate_offer_criterion.SellerRebateOfferCriterion(
                        offers = [
                            allegro_api.models.seller_rebate_offer_criterion_offers.SellerRebateOfferCriterion_offers(
                                id = '1233432', 
                                quantity = 5, 
                                promotion_entry_point = False, )
                            ], 
                        type = 'CONTAINS_OFFERS', )
                    ], 
                status = 'ACTIVE'
            )
        else :
            return SellerRebateDto(
                benefits = [
                    allegro_api.models.benefit.Benefit(
                        specification = allegro_api.models.benefit_specification.BenefitSpecification(
                            type = '0', ), )
                    ],
                id = '7c9a76d3-9fd0-4d13-a4ce-5d49bec12c79',
                offer_criteria = [
                    allegro_api.models.seller_rebate_offer_criterion.SellerRebateOfferCriterion(
                        offers = [
                            allegro_api.models.seller_rebate_offer_criterion_offers.SellerRebateOfferCriterion_offers(
                                id = '1233432', 
                                quantity = 5, 
                                promotion_entry_point = False, )
                            ], 
                        type = 'CONTAINS_OFFERS', )
                    ],
                status = 'ACTIVE',
        )

    def testSellerRebateDto(self):
        """Test SellerRebateDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class ClassifiedsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def assign_classified_packages_using_put(self, offer_id, classified_packages, **kwargs):  # noqa: E501
        """Assign packages to a classified  # noqa: E501

        Use this resource to assign classified packages to an offer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign_classified_packages_using_put(offer_id, classified_packages, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: The offer ID. (required)
        :param ClassifiedPackages classified_packages: Packages that should be assigned to the classified. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.assign_classified_packages_using_put_with_http_info(offer_id, classified_packages, **kwargs)  # noqa: E501

    def assign_classified_packages_using_put_with_http_info(self, offer_id, classified_packages, **kwargs):  # noqa: E501
        """Assign packages to a classified  # noqa: E501

        Use this resource to assign classified packages to an offer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign_classified_packages_using_put_with_http_info(offer_id, classified_packages, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: The offer ID. (required)
        :param ClassifiedPackages classified_packages: Packages that should be assigned to the classified. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['offer_id', 'classified_packages']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assign_classified_packages_using_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'offer_id' is set
        if self.api_client.client_side_validation and ('offer_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['offer_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `offer_id` when calling `assign_classified_packages_using_put`")  # noqa: E501
        # verify the required parameter 'classified_packages' is set
        if self.api_client.client_side_validation and ('classified_packages' not in local_var_params or  # noqa: E501
                                                        local_var_params['classified_packages'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `classified_packages` when calling `assign_classified_packages_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'offer_id' in local_var_params:
            path_params['offerId'] = local_var_params['offer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'classified_packages' in local_var_params:
            body_params = local_var_params['classified_packages']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offer-classifieds-packages/{offerId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_classified_package_configuration_using_get(self, package_id, **kwargs):  # noqa: E501
        """Get the configuration of a package  # noqa: E501

        Use this resource to retrieve the configuration of a classifieds package.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_classified_package_configuration_using_get(package_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str package_id: The classifieds package ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ClassifiedPackageConfig
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_classified_package_configuration_using_get_with_http_info(package_id, **kwargs)  # noqa: E501

    def get_classified_package_configuration_using_get_with_http_info(self, package_id, **kwargs):  # noqa: E501
        """Get the configuration of a package  # noqa: E501

        Use this resource to retrieve the configuration of a classifieds package.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_classified_package_configuration_using_get_with_http_info(package_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str package_id: The classifieds package ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ClassifiedPackageConfig, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['package_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_classified_package_configuration_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'package_id' is set
        if self.api_client.client_side_validation and ('package_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['package_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `package_id` when calling `get_classified_package_configuration_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'package_id' in local_var_params:
            path_params['packageId'] = local_var_params['package_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/classifieds-packages/{packageId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ClassifiedPackageConfig',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_classified_package_configurations_for_category_using_get(self, category_id, **kwargs):  # noqa: E501
        """Get configurations of packages  # noqa: E501

        Use this resource to retrieve configurations of classifieds packages for a category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_classified_package_configurations_for_category_using_get(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str category_id: The category ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ClassifiedPackageConfigs
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_classified_package_configurations_for_category_using_get_with_http_info(category_id, **kwargs)  # noqa: E501

    def get_classified_package_configurations_for_category_using_get_with_http_info(self, category_id, **kwargs):  # noqa: E501
        """Get configurations of packages  # noqa: E501

        Use this resource to retrieve configurations of classifieds packages for a category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_classified_package_configurations_for_category_using_get_with_http_info(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str category_id: The category ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ClassifiedPackageConfigs, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['category_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_classified_package_configurations_for_category_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'category_id' is set
        if self.api_client.client_side_validation and ('category_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['category_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `category_id` when calling `get_classified_package_configurations_for_category_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'category_id' in local_var_params and local_var_params['category_id'] is not None:  # noqa: E501
            query_params.append(('category.id', local_var_params['category_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/classifieds-packages', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ClassifiedPackageConfigs',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_classified_packages_using_get(self, offer_id, **kwargs):  # noqa: E501
        """Get classified packages assigned to an offer  # noqa: E501

        Use this resource to retrieve classified packages currently assigned to an offer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_classified_packages_using_get(offer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: Offer ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ClassifiedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_classified_packages_using_get_with_http_info(offer_id, **kwargs)  # noqa: E501

    def get_classified_packages_using_get_with_http_info(self, offer_id, **kwargs):  # noqa: E501
        """Get classified packages assigned to an offer  # noqa: E501

        Use this resource to retrieve classified packages currently assigned to an offer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_classified_packages_using_get_with_http_info(offer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: Offer ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ClassifiedResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['offer_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_classified_packages_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'offer_id' is set
        if self.api_client.client_side_validation and ('offer_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['offer_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `offer_id` when calling `get_classified_packages_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'offer_id' in local_var_params:
            path_params['offerId'] = local_var_params['offer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offer-classifieds-packages/{offerId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ClassifiedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.checkout_form_invoice_info import CheckoutFormInvoiceInfo  # noqa: E501
from allegro_api.rest import ApiException

class TestCheckoutFormInvoiceInfo(unittest.TestCase):
    """CheckoutFormInvoiceInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CheckoutFormInvoiceInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.checkout_form_invoice_info.CheckoutFormInvoiceInfo()  # noqa: E501
        if include_optional :
            return CheckoutFormInvoiceInfo(
                required = True, 
                address = allegro_api.models.checkout_form_invoice_address.CheckoutFormInvoiceAddress(
                    street = 'Grunwaldzka 182', 
                    city = 'Poznań', 
                    zip_code = '60-166', 
                    country_code = 'PL', 
                    company = allegro_api.models.checkout_form_invoice_address_company.CheckoutFormInvoiceAddressCompany(
                        name = 'Udix Sp. z o.o.', 
                        tax_id = '0', ), 
                    natural_person = allegro_api.models.checkout_form_invoice_address_natural_person.CheckoutFormInvoiceAddressNaturalPerson(
                        first_name = 'Jan', 
                        last_name = 'Kowalski', ), )
            )
        else :
            return CheckoutFormInvoiceInfo(
                required = True,
        )

    def testCheckoutFormInvoiceInfo(self):
        """Test CheckoutFormInvoiceInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class Location(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'city': 'str',
        'country_code': 'str',
        'post_code': 'str',
        'province': 'str'
    }

    attribute_map = {
        'city': 'city',
        'country_code': 'countryCode',
        'post_code': 'postCode',
        'province': 'province'
    }

    def __init__(self, city=None, country_code=None, post_code=None, province=None, local_vars_configuration=None):  # noqa: E501
        """Location - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._city = None
        self._country_code = None
        self._post_code = None
        self._province = None
        self.discriminator = None

        if city is not None:
            self.city = city
        if country_code is not None:
            self.country_code = country_code
        if post_code is not None:
            self.post_code = post_code
        if province is not None:
            self.province = province

    @property
    def city(self):
        """Gets the city of this Location.  # noqa: E501


        :return: The city of this Location.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this Location.


        :param city: The city of this Location.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                city is not None and len(city) > 35):
            raise ValueError("Invalid value for `city`, length must be less than or equal to `35`")  # noqa: E501

        self._city = city

    @property
    def country_code(self):
        """Gets the country_code of this Location.  # noqa: E501


        :return: The country_code of this Location.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this Location.


        :param country_code: The country_code of this Location.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def post_code(self):
        """Gets the post_code of this Location.  # noqa: E501


        :return: The post_code of this Location.  # noqa: E501
        :rtype: str
        """
        return self._post_code

    @post_code.setter
    def post_code(self, post_code):
        """Sets the post_code of this Location.


        :param post_code: The post_code of this Location.  # noqa: E501
        :type: str
        """

        self._post_code = post_code

    @property
    def province(self):
        """Gets the province of this Location.  # noqa: E501

        This field is mandatory if countryCode is set to \"PL\", for other values, currently, it is ignored. For countryCode equalling \"PL\", this field must be set to one of the following: DOLNOSLASKIE, KUJAWSKO_POMORSKIE, LUBELSKIE, LUBUSKIE, LODZKIE, MALOPOLSKIE, MAZOWIECKIE, OPOLSKIE, PODKARPACKIE, PODLASKIE, POMORSKIE, SLASKIE, SWIETOKRZYSKIE, WARMINSKO_MAZURSKIE, WIELKOPOLSKIE, ZACHODNIOPOMORSKIE.  # noqa: E501

        :return: The province of this Location.  # noqa: E501
        :rtype: str
        """
        return self._province

    @province.setter
    def province(self, province):
        """Sets the province of this Location.

        This field is mandatory if countryCode is set to \"PL\", for other values, currently, it is ignored. For countryCode equalling \"PL\", this field must be set to one of the following: DOLNOSLASKIE, KUJAWSKO_POMORSKIE, LUBELSKIE, LUBUSKIE, LODZKIE, MALOPOLSKIE, MAZOWIECKIE, OPOLSKIE, PODKARPACKIE, PODLASKIE, POMORSKIE, SLASKIE, SWIETOKRZYSKIE, WARMINSKO_MAZURSKIE, WIELKOPOLSKIE, ZACHODNIOPOMORSKIE.  # noqa: E501

        :param province: The province of this Location.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                province is not None and len(province) > 50):
            raise ValueError("Invalid value for `province`, length must be less than or equal to `50`")  # noqa: E501

        self._province = province

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Location):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Location):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.offer_rating import OfferRating  # noqa: E501
from allegro_api.rest import ApiException

class TestOfferRating(unittest.TestCase):
    """OfferRating unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OfferRating
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.offer_rating.OfferRating()  # noqa: E501
        if include_optional :
            return OfferRating(
                average_score = '4.0', 
                score_distribution = [{"name":"5","count":1},{"name":"4","count":3},{"name":"3","count":1},{"name":"2","count":0},{"name":"1","count":0}], 
                total_responses = 5, 
                size_feedback = [{"name":"BIGGER","count":0},{"name":"FIT","count":2},{"name":"SMALLER","count":0}]
            )
        else :
            return OfferRating(
        )

    def testOfferRating(self):
        """Test OfferRating"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class CategoryOptionsDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'advertisement': 'bool',
        'advertisement_price_optional': 'bool',
        'variants_by_color_pattern_allowed': 'bool',
        'offers_with_product_publication_enabled': 'bool',
        'product_creation_enabled': 'bool',
        'product_ean_required': 'bool'
    }

    attribute_map = {
        'advertisement': 'advertisement',
        'advertisement_price_optional': 'advertisementPriceOptional',
        'variants_by_color_pattern_allowed': 'variantsByColorPatternAllowed',
        'offers_with_product_publication_enabled': 'offersWithProductPublicationEnabled',
        'product_creation_enabled': 'productCreationEnabled',
        'product_ean_required': 'productEANRequired'
    }

    def __init__(self, advertisement=None, advertisement_price_optional=None, variants_by_color_pattern_allowed=None, offers_with_product_publication_enabled=None, product_creation_enabled=None, product_ean_required=None, local_vars_configuration=None):  # noqa: E501
        """CategoryOptionsDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._advertisement = None
        self._advertisement_price_optional = None
        self._variants_by_color_pattern_allowed = None
        self._offers_with_product_publication_enabled = None
        self._product_creation_enabled = None
        self._product_ean_required = None
        self.discriminator = None

        if advertisement is not None:
            self.advertisement = advertisement
        if advertisement_price_optional is not None:
            self.advertisement_price_optional = advertisement_price_optional
        if variants_by_color_pattern_allowed is not None:
            self.variants_by_color_pattern_allowed = variants_by_color_pattern_allowed
        if offers_with_product_publication_enabled is not None:
            self.offers_with_product_publication_enabled = offers_with_product_publication_enabled
        if product_creation_enabled is not None:
            self.product_creation_enabled = product_creation_enabled
        if product_ean_required is not None:
            self.product_ean_required = product_ean_required

    @property
    def advertisement(self):
        """Gets the advertisement of this CategoryOptionsDto.  # noqa: E501

        Indicates whether offers of type ADVERTISEMENT can be listed in this category.  # noqa: E501

        :return: The advertisement of this CategoryOptionsDto.  # noqa: E501
        :rtype: bool
        """
        return self._advertisement

    @advertisement.setter
    def advertisement(self, advertisement):
        """Sets the advertisement of this CategoryOptionsDto.

        Indicates whether offers of type ADVERTISEMENT can be listed in this category.  # noqa: E501

        :param advertisement: The advertisement of this CategoryOptionsDto.  # noqa: E501
        :type: bool
        """

        self._advertisement = advertisement

    @property
    def advertisement_price_optional(self):
        """Gets the advertisement_price_optional of this CategoryOptionsDto.  # noqa: E501

        Indicates whether advertisements listed in this category must have a price given. If the value is `true` then you don't have to provide a price when listing an advertisement in this category.  # noqa: E501

        :return: The advertisement_price_optional of this CategoryOptionsDto.  # noqa: E501
        :rtype: bool
        """
        return self._advertisement_price_optional

    @advertisement_price_optional.setter
    def advertisement_price_optional(self, advertisement_price_optional):
        """Sets the advertisement_price_optional of this CategoryOptionsDto.

        Indicates whether advertisements listed in this category must have a price given. If the value is `true` then you don't have to provide a price when listing an advertisement in this category.  # noqa: E501

        :param advertisement_price_optional: The advertisement_price_optional of this CategoryOptionsDto.  # noqa: E501
        :type: bool
        """

        self._advertisement_price_optional = advertisement_price_optional

    @property
    def variants_by_color_pattern_allowed(self):
        """Gets the variants_by_color_pattern_allowed of this CategoryOptionsDto.  # noqa: E501

        Indicates whether you can combine offers from this category into variant sets based on the color and pattern.  # noqa: E501

        :return: The variants_by_color_pattern_allowed of this CategoryOptionsDto.  # noqa: E501
        :rtype: bool
        """
        return self._variants_by_color_pattern_allowed

    @variants_by_color_pattern_allowed.setter
    def variants_by_color_pattern_allowed(self, variants_by_color_pattern_allowed):
        """Sets the variants_by_color_pattern_allowed of this CategoryOptionsDto.

        Indicates whether you can combine offers from this category into variant sets based on the color and pattern.  # noqa: E501

        :param variants_by_color_pattern_allowed: The variants_by_color_pattern_allowed of this CategoryOptionsDto.  # noqa: E501
        :type: bool
        """

        self._variants_by_color_pattern_allowed = variants_by_color_pattern_allowed

    @property
    def offers_with_product_publication_enabled(self):
        """Gets the offers_with_product_publication_enabled of this CategoryOptionsDto.  # noqa: E501

        Information whether the category supports assigning offers to a product.  # noqa: E501

        :return: The offers_with_product_publication_enabled of this CategoryOptionsDto.  # noqa: E501
        :rtype: bool
        """
        return self._offers_with_product_publication_enabled

    @offers_with_product_publication_enabled.setter
    def offers_with_product_publication_enabled(self, offers_with_product_publication_enabled):
        """Sets the offers_with_product_publication_enabled of this CategoryOptionsDto.

        Information whether the category supports assigning offers to a product.  # noqa: E501

        :param offers_with_product_publication_enabled: The offers_with_product_publication_enabled of this CategoryOptionsDto.  # noqa: E501
        :type: bool
        """

        self._offers_with_product_publication_enabled = offers_with_product_publication_enabled

    @property
    def product_creation_enabled(self):
        """Gets the product_creation_enabled of this CategoryOptionsDto.  # noqa: E501

        Indicates whether the category supports creating products.  # noqa: E501

        :return: The product_creation_enabled of this CategoryOptionsDto.  # noqa: E501
        :rtype: bool
        """
        return self._product_creation_enabled

    @product_creation_enabled.setter
    def product_creation_enabled(self, product_creation_enabled):
        """Sets the product_creation_enabled of this CategoryOptionsDto.

        Indicates whether the category supports creating products.  # noqa: E501

        :param product_creation_enabled: The product_creation_enabled of this CategoryOptionsDto.  # noqa: E501
        :type: bool
        """

        self._product_creation_enabled = product_creation_enabled

    @property
    def product_ean_required(self):
        """Gets the product_ean_required of this CategoryOptionsDto.  # noqa: E501

        Indicates whether at least one EAN is required when creating products.  # noqa: E501

        :return: The product_ean_required of this CategoryOptionsDto.  # noqa: E501
        :rtype: bool
        """
        return self._product_ean_required

    @product_ean_required.setter
    def product_ean_required(self, product_ean_required):
        """Sets the product_ean_required of this CategoryOptionsDto.

        Indicates whether at least one EAN is required when creating products.  # noqa: E501

        :param product_ean_required: The product_ean_required of this CategoryOptionsDto.  # noqa: E501
        :type: bool
        """

        self._product_ean_required = product_ean_required

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CategoryOptionsDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CategoryOptionsDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.offer_variants_api import OfferVariantsApi  # noqa: E501
from allegro_api.rest import ApiException


class TestOfferVariantsApi(unittest.TestCase):
    """OfferVariantsApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.offer_variants_api.OfferVariantsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_or_update_variant_set(self):
        """Test case for create_or_update_variant_set

        [BETA] Create or update variant set  # noqa: E501
        """
        pass

    def test_delete_variant_set(self):
        """Test case for delete_variant_set

        [BETA] Delete a variant set  # noqa: E501
        """
        pass

    def test_get_variant_set(self):
        """Test case for get_variant_set

        [BETA] Get a variant set  # noqa: E501
        """
        pass

    def test_get_variant_sets(self):
        """Test case for get_variant_sets

        [BETA] Get the user's variant sets  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class ShippingRate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'delivery_method': 'ShippingRateDeliveryMethod',
        'max_quantity_per_package': 'int',
        'first_item_rate': 'ShippingRateFirstItemRate',
        'next_item_rate': 'ShippingRateNextItemRate',
        'shipping_time': 'ShippingRateShippingTime'
    }

    attribute_map = {
        'delivery_method': 'deliveryMethod',
        'max_quantity_per_package': 'maxQuantityPerPackage',
        'first_item_rate': 'firstItemRate',
        'next_item_rate': 'nextItemRate',
        'shipping_time': 'shippingTime'
    }

    def __init__(self, delivery_method=None, max_quantity_per_package=None, first_item_rate=None, next_item_rate=None, shipping_time=None, local_vars_configuration=None):  # noqa: E501
        """ShippingRate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._delivery_method = None
        self._max_quantity_per_package = None
        self._first_item_rate = None
        self._next_item_rate = None
        self._shipping_time = None
        self.discriminator = None

        self.delivery_method = delivery_method
        self.max_quantity_per_package = max_quantity_per_package
        self.first_item_rate = first_item_rate
        self.next_item_rate = next_item_rate
        if shipping_time is not None:
            self.shipping_time = shipping_time

    @property
    def delivery_method(self):
        """Gets the delivery_method of this ShippingRate.  # noqa: E501


        :return: The delivery_method of this ShippingRate.  # noqa: E501
        :rtype: ShippingRateDeliveryMethod
        """
        return self._delivery_method

    @delivery_method.setter
    def delivery_method(self, delivery_method):
        """Sets the delivery_method of this ShippingRate.


        :param delivery_method: The delivery_method of this ShippingRate.  # noqa: E501
        :type: ShippingRateDeliveryMethod
        """
        if self.local_vars_configuration.client_side_validation and delivery_method is None:  # noqa: E501
            raise ValueError("Invalid value for `delivery_method`, must not be `None`")  # noqa: E501

        self._delivery_method = delivery_method

    @property
    def max_quantity_per_package(self):
        """Gets the max_quantity_per_package of this ShippingRate.  # noqa: E501

        Maximum quantity per package for the given delivery method. Minimum value is 1.  # noqa: E501

        :return: The max_quantity_per_package of this ShippingRate.  # noqa: E501
        :rtype: int
        """
        return self._max_quantity_per_package

    @max_quantity_per_package.setter
    def max_quantity_per_package(self, max_quantity_per_package):
        """Sets the max_quantity_per_package of this ShippingRate.

        Maximum quantity per package for the given delivery method. Minimum value is 1.  # noqa: E501

        :param max_quantity_per_package: The max_quantity_per_package of this ShippingRate.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and max_quantity_per_package is None:  # noqa: E501
            raise ValueError("Invalid value for `max_quantity_per_package`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_quantity_per_package is not None and max_quantity_per_package < 1):  # noqa: E501
            raise ValueError("Invalid value for `max_quantity_per_package`, must be a value greater than or equal to `1`")  # noqa: E501

        self._max_quantity_per_package = max_quantity_per_package

    @property
    def first_item_rate(self):
        """Gets the first_item_rate of this ShippingRate.  # noqa: E501


        :return: The first_item_rate of this ShippingRate.  # noqa: E501
        :rtype: ShippingRateFirstItemRate
        """
        return self._first_item_rate

    @first_item_rate.setter
    def first_item_rate(self, first_item_rate):
        """Sets the first_item_rate of this ShippingRate.


        :param first_item_rate: The first_item_rate of this ShippingRate.  # noqa: E501
        :type: ShippingRateFirstItemRate
        """
        if self.local_vars_configuration.client_side_validation and first_item_rate is None:  # noqa: E501
            raise ValueError("Invalid value for `first_item_rate`, must not be `None`")  # noqa: E501

        self._first_item_rate = first_item_rate

    @property
    def next_item_rate(self):
        """Gets the next_item_rate of this ShippingRate.  # noqa: E501


        :return: The next_item_rate of this ShippingRate.  # noqa: E501
        :rtype: ShippingRateNextItemRate
        """
        return self._next_item_rate

    @next_item_rate.setter
    def next_item_rate(self, next_item_rate):
        """Sets the next_item_rate of this ShippingRate.


        :param next_item_rate: The next_item_rate of this ShippingRate.  # noqa: E501
        :type: ShippingRateNextItemRate
        """
        if self.local_vars_configuration.client_side_validation and next_item_rate is None:  # noqa: E501
            raise ValueError("Invalid value for `next_item_rate`, must not be `None`")  # noqa: E501

        self._next_item_rate = next_item_rate

    @property
    def shipping_time(self):
        """Gets the shipping_time of this ShippingRate.  # noqa: E501


        :return: The shipping_time of this ShippingRate.  # noqa: E501
        :rtype: ShippingRateShippingTime
        """
        return self._shipping_time

    @shipping_time.setter
    def shipping_time(self, shipping_time):
        """Sets the shipping_time of this ShippingRate.


        :param shipping_time: The shipping_time of this ShippingRate.  # noqa: E501
        :type: ShippingRateShippingTime
        """

        self._shipping_time = shipping_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShippingRate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ShippingRate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.disputes_api import DisputesApi  # noqa: E501
from allegro_api.rest import ApiException


class TestDisputesApi(unittest.TestCase):
    """DisputesApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.disputes_api.DisputesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_message_to_dispute_using_post(self):
        """Test case for add_message_to_dispute_using_post

        Add a message to a dispute  # noqa: E501
        """
        pass

    def test_create_an_attachment_using_post(self):
        """Test case for create_an_attachment_using_post

        Create an attachment declaration  # noqa: E501
        """
        pass

    def test_get_attachment_using_get(self):
        """Test case for get_attachment_using_get

        Get an attachment  # noqa: E501
        """
        pass

    def test_get_dispute_using_get(self):
        """Test case for get_dispute_using_get

        Get a single dispute  # noqa: E501
        """
        pass

    def test_get_list_of_disputes_using_get(self):
        """Test case for get_list_of_disputes_using_get

        Get the user's disputes  # noqa: E501
        """
        pass

    def test_get_messages_from_dispute_using_get(self):
        """Test case for get_messages_from_dispute_using_get

        Get the messages within a dispute  # noqa: E501
        """
        pass

    def test_upload_dispute_attachment_using_put(self):
        """Test case for upload_dispute_attachment_using_put

        Upload a dispute message attachment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class CategoryParameter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'type': 'str',
        'required': 'bool',
        'unit': 'str',
        'options': 'CategoryParameterOptions'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'type': 'type',
        'required': 'required',
        'unit': 'unit',
        'options': 'options'
    }

    discriminator_value_class_map = {
        'FloatCategoryParameter': 'FloatCategoryParameter',
        'IntegerCategoryParameter': 'IntegerCategoryParameter',
        'DictionaryCategoryParameter': 'DictionaryCategoryParameter',
        'StringCategoryParameter': 'StringCategoryParameter'
    }

    def __init__(self, id=None, name=None, type=None, required=None, unit=None, options=None, local_vars_configuration=None):  # noqa: E501
        """CategoryParameter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._type = None
        self._required = None
        self._unit = None
        self._options = None
        self.discriminator = 'type'

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        self.type = type
        if required is not None:
            self.required = required
        if unit is not None:
            self.unit = unit
        if options is not None:
            self.options = options

    @property
    def id(self):
        """Gets the id of this CategoryParameter.  # noqa: E501

        The ID of the parameter.  # noqa: E501

        :return: The id of this CategoryParameter.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CategoryParameter.

        The ID of the parameter.  # noqa: E501

        :param id: The id of this CategoryParameter.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this CategoryParameter.  # noqa: E501

        The name of the parameter in Polish.  # noqa: E501

        :return: The name of this CategoryParameter.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CategoryParameter.

        The name of the parameter in Polish.  # noqa: E501

        :param name: The name of this CategoryParameter.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this CategoryParameter.  # noqa: E501

        The type of the parameter. Other fields in this structure may appear based on the type of the parameter.  # noqa: E501

        :return: The type of this CategoryParameter.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CategoryParameter.

        The type of the parameter. Other fields in this structure may appear based on the type of the parameter.  # noqa: E501

        :param type: The type of this CategoryParameter.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def required(self):
        """Gets the required of this CategoryParameter.  # noqa: E501

        Indicates whether the value of this parameter must be set in an offer. Offers without required parameters set cannot be published.  # noqa: E501

        :return: The required of this CategoryParameter.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this CategoryParameter.

        Indicates whether the value of this parameter must be set in an offer. Offers without required parameters set cannot be published.  # noqa: E501

        :param required: The required of this CategoryParameter.  # noqa: E501
        :type: bool
        """

        self._required = required

    @property
    def unit(self):
        """Gets the unit of this CategoryParameter.  # noqa: E501

        The unit in which values of the parameter are used. May be `null`.  # noqa: E501

        :return: The unit of this CategoryParameter.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this CategoryParameter.

        The unit in which values of the parameter are used. May be `null`.  # noqa: E501

        :param unit: The unit of this CategoryParameter.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def options(self):
        """Gets the options of this CategoryParameter.  # noqa: E501


        :return: The options of this CategoryParameter.  # noqa: E501
        :rtype: CategoryParameterOptions
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this CategoryParameter.


        :param options: The options of this CategoryParameter.  # noqa: E501
        :type: CategoryParameterOptions
        """

        self._options = options

    def get_real_child_model(self, data):
        """Returns the real base class specified by the discriminator"""
        discriminator_key = self.attribute_map[self.discriminator]
        discriminator_value = data[discriminator_key]
        return self.discriminator_value_class_map.get(discriminator_value)

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CategoryParameter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CategoryParameter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class DeliverySettingsDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'free_delivery': 'DeliverySettingsDtoFreeDelivery',
        'join_policy': 'DeliverySettingsDtoJoinPolicy',
        'custom_cost': 'DeliverySettingsDtoCustomCost',
        'updated_at': 'str'
    }

    attribute_map = {
        'free_delivery': 'freeDelivery',
        'join_policy': 'joinPolicy',
        'custom_cost': 'customCost',
        'updated_at': 'updatedAt'
    }

    def __init__(self, free_delivery=None, join_policy=None, custom_cost=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """DeliverySettingsDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._free_delivery = None
        self._join_policy = None
        self._custom_cost = None
        self._updated_at = None
        self.discriminator = None

        if free_delivery is not None:
            self.free_delivery = free_delivery
        if join_policy is not None:
            self.join_policy = join_policy
        if custom_cost is not None:
            self.custom_cost = custom_cost
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def free_delivery(self):
        """Gets the free_delivery of this DeliverySettingsDto.  # noqa: E501


        :return: The free_delivery of this DeliverySettingsDto.  # noqa: E501
        :rtype: DeliverySettingsDtoFreeDelivery
        """
        return self._free_delivery

    @free_delivery.setter
    def free_delivery(self, free_delivery):
        """Sets the free_delivery of this DeliverySettingsDto.


        :param free_delivery: The free_delivery of this DeliverySettingsDto.  # noqa: E501
        :type: DeliverySettingsDtoFreeDelivery
        """

        self._free_delivery = free_delivery

    @property
    def join_policy(self):
        """Gets the join_policy of this DeliverySettingsDto.  # noqa: E501


        :return: The join_policy of this DeliverySettingsDto.  # noqa: E501
        :rtype: DeliverySettingsDtoJoinPolicy
        """
        return self._join_policy

    @join_policy.setter
    def join_policy(self, join_policy):
        """Sets the join_policy of this DeliverySettingsDto.


        :param join_policy: The join_policy of this DeliverySettingsDto.  # noqa: E501
        :type: DeliverySettingsDtoJoinPolicy
        """

        self._join_policy = join_policy

    @property
    def custom_cost(self):
        """Gets the custom_cost of this DeliverySettingsDto.  # noqa: E501


        :return: The custom_cost of this DeliverySettingsDto.  # noqa: E501
        :rtype: DeliverySettingsDtoCustomCost
        """
        return self._custom_cost

    @custom_cost.setter
    def custom_cost(self, custom_cost):
        """Sets the custom_cost of this DeliverySettingsDto.


        :param custom_cost: The custom_cost of this DeliverySettingsDto.  # noqa: E501
        :type: DeliverySettingsDtoCustomCost
        """

        self._custom_cost = custom_cost

    @property
    def updated_at(self):
        """Gets the updated_at of this DeliverySettingsDto.  # noqa: E501

        Date and time of the last modification of the set in UTC ISO 8601 format. When updating (Put) settings the field is ignored.  # noqa: E501

        :return: The updated_at of this DeliverySettingsDto.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DeliverySettingsDto.

        Date and time of the last modification of the set in UTC ISO 8601 format. When updating (Put) settings the field is ignored.  # noqa: E501

        :param updated_at: The updated_at of this DeliverySettingsDto.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverySettingsDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverySettingsDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.products_api import ProductsApi  # noqa: E501
from allegro_api.rest import ApiException


class TestProductsApi(unittest.TestCase):
    """ProductsApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.products_api.ProductsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_flat_product_parameters_using_get(self):
        """Test case for get_flat_product_parameters_using_get

        Get product parameters available in given category  # noqa: E501
        """
        pass

    def test_get_sale_product(self):
        """Test case for get_sale_product

        Get all data of the particular product  # noqa: E501
        """
        pass

    def test_get_sale_products(self):
        """Test case for get_sale_products

        Get search products results  # noqa: E501
        """
        pass

    def test_propose_sale_product(self):
        """Test case for propose_sale_product

        Propose a product  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class CompatibilityListManualAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'items': 'list[CompatibilityListItem]'
    }

    attribute_map = {
        'items': 'items'
    }

    def __init__(self, items=None, local_vars_configuration=None):  # noqa: E501
        """CompatibilityListManualAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._items = None
        self.discriminator = None

        self.items = items

    @property
    def items(self):
        """Gets the items of this CompatibilityListManualAllOf.  # noqa: E501

        List of the compatible items. Maximum number of elements on the list depends on type of included compatible items. Configuration and details concerning the compatible items in selected category are provided in the response for GET <a href=\"/documentation/#tag/Compatibility-List/paths/~1sale~1compatibility-list~1supported-categories/get\"> supported-categories</a> resource in `validationRules` object.  # noqa: E501

        :return: The items of this CompatibilityListManualAllOf.  # noqa: E501
        :rtype: list[CompatibilityListItem]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this CompatibilityListManualAllOf.

        List of the compatible items. Maximum number of elements on the list depends on type of included compatible items. Configuration and details concerning the compatible items in selected category are provided in the response for GET <a href=\"/documentation/#tag/Compatibility-List/paths/~1sale~1compatibility-list~1supported-categories/get\"> supported-categories</a> resource in `validationRules` object.  # noqa: E501

        :param items: The items of this CompatibilityListManualAllOf.  # noqa: E501
        :type: list[CompatibilityListItem]
        """
        if self.local_vars_configuration.client_side_validation and items is None:  # noqa: E501
            raise ValueError("Invalid value for `items`, must not be `None`")  # noqa: E501

        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompatibilityListManualAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CompatibilityListManualAllOf):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.compatibility_list_id_item_all_of import CompatibilityListIdItemAllOf  # noqa: E501
from allegro_api.rest import ApiException

class TestCompatibilityListIdItemAllOf(unittest.TestCase):
    """CompatibilityListIdItemAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CompatibilityListIdItemAllOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.compatibility_list_id_item_all_of.CompatibilityListIdItemAllOf()  # noqa: E501
        if include_optional :
            return CompatibilityListIdItemAllOf(
                type = 'ID', 
                id = '0006563f-f2b9-44ea-ae67-4678679be1f1', 
                text = 'CITROËN C6 (TD_) 2005/09-2011/12 2.7 HDi 204KM/150kW', 
                additional_info = [
                    allegro_api.models.compatibility_list_id_item_additional_info.CompatibilityListIdItemAdditionalInfo(
                        value = 'only for versions with BDX engine code', )
                    ]
            )
        else :
            return CompatibilityListIdItemAllOf(
                id = '0006563f-f2b9-44ea-ae67-4678679be1f1',
        )

    def testCompatibilityListIdItemAllOf(self):
        """Test CompatibilityListIdItemAllOf"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class Offer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'additional_services': 'JustId',
        'after_sales_services': 'AfterSalesServices',
        'attachments': 'list[Attachment]',
        'category': 'Category',
        'compatibility_list': 'CompatibilityList',
        'contact': 'JustId',
        'created_at': 'datetime',
        'delivery': 'Delivery',
        'description': 'StandardizedDescription',
        'ean': 'str',
        'external': 'ExternalId',
        'id': 'str',
        'images': 'list[ImageUrl]',
        'location': 'Location',
        'name': 'str',
        'parameters': 'list[Parameter]',
        'payments': 'Payments',
        'product': 'JustId',
        'promotion': 'Promotion',
        'publication': 'Publication',
        'selling_mode': 'SellingMode',
        'size_table': 'JustId',
        'stock': 'Stock',
        'tecdoc_specification': 'TecdocSpecification',
        'updated_at': 'datetime',
        'validation': 'Validation'
    }

    attribute_map = {
        'additional_services': 'additionalServices',
        'after_sales_services': 'afterSalesServices',
        'attachments': 'attachments',
        'category': 'category',
        'compatibility_list': 'compatibilityList',
        'contact': 'contact',
        'created_at': 'createdAt',
        'delivery': 'delivery',
        'description': 'description',
        'ean': 'ean',
        'external': 'external',
        'id': 'id',
        'images': 'images',
        'location': 'location',
        'name': 'name',
        'parameters': 'parameters',
        'payments': 'payments',
        'product': 'product',
        'promotion': 'promotion',
        'publication': 'publication',
        'selling_mode': 'sellingMode',
        'size_table': 'sizeTable',
        'stock': 'stock',
        'tecdoc_specification': 'tecdocSpecification',
        'updated_at': 'updatedAt',
        'validation': 'validation'
    }

    def __init__(self, additional_services=None, after_sales_services=None, attachments=None, category=None, compatibility_list=None, contact=None, created_at=None, delivery=None, description=None, ean=None, external=None, id=None, images=None, location=None, name=None, parameters=None, payments=None, product=None, promotion=None, publication=None, selling_mode=None, size_table=None, stock=None, tecdoc_specification=None, updated_at=None, validation=None, local_vars_configuration=None):  # noqa: E501
        """Offer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._additional_services = None
        self._after_sales_services = None
        self._attachments = None
        self._category = None
        self._compatibility_list = None
        self._contact = None
        self._created_at = None
        self._delivery = None
        self._description = None
        self._ean = None
        self._external = None
        self._id = None
        self._images = None
        self._location = None
        self._name = None
        self._parameters = None
        self._payments = None
        self._product = None
        self._promotion = None
        self._publication = None
        self._selling_mode = None
        self._size_table = None
        self._stock = None
        self._tecdoc_specification = None
        self._updated_at = None
        self._validation = None
        self.discriminator = None

        if additional_services is not None:
            self.additional_services = additional_services
        if after_sales_services is not None:
            self.after_sales_services = after_sales_services
        if attachments is not None:
            self.attachments = attachments
        if category is not None:
            self.category = category
        if compatibility_list is not None:
            self.compatibility_list = compatibility_list
        if contact is not None:
            self.contact = contact
        if created_at is not None:
            self.created_at = created_at
        if delivery is not None:
            self.delivery = delivery
        if description is not None:
            self.description = description
        if ean is not None:
            self.ean = ean
        if external is not None:
            self.external = external
        if id is not None:
            self.id = id
        if images is not None:
            self.images = images
        if location is not None:
            self.location = location
        self.name = name
        if parameters is not None:
            self.parameters = parameters
        if payments is not None:
            self.payments = payments
        if product is not None:
            self.product = product
        if promotion is not None:
            self.promotion = promotion
        if publication is not None:
            self.publication = publication
        if selling_mode is not None:
            self.selling_mode = selling_mode
        if size_table is not None:
            self.size_table = size_table
        if stock is not None:
            self.stock = stock
        if tecdoc_specification is not None:
            self.tecdoc_specification = tecdoc_specification
        if updated_at is not None:
            self.updated_at = updated_at
        if validation is not None:
            self.validation = validation

    @property
    def additional_services(self):
        """Gets the additional_services of this Offer.  # noqa: E501


        :return: The additional_services of this Offer.  # noqa: E501
        :rtype: JustId
        """
        return self._additional_services

    @additional_services.setter
    def additional_services(self, additional_services):
        """Sets the additional_services of this Offer.


        :param additional_services: The additional_services of this Offer.  # noqa: E501
        :type: JustId
        """

        self._additional_services = additional_services

    @property
    def after_sales_services(self):
        """Gets the after_sales_services of this Offer.  # noqa: E501


        :return: The after_sales_services of this Offer.  # noqa: E501
        :rtype: AfterSalesServices
        """
        return self._after_sales_services

    @after_sales_services.setter
    def after_sales_services(self, after_sales_services):
        """Sets the after_sales_services of this Offer.


        :param after_sales_services: The after_sales_services of this Offer.  # noqa: E501
        :type: AfterSalesServices
        """

        self._after_sales_services = after_sales_services

    @property
    def attachments(self):
        """Gets the attachments of this Offer.  # noqa: E501

        List of offer attachments. You can attach up to 7 files to the offer – one per each attachment type as described in <a href=\"/documentation/#operation/createOfferAttachmentUsingPOST\" target=\"_blank\">uploading offer attachments flow</a>.  # noqa: E501

        :return: The attachments of this Offer.  # noqa: E501
        :rtype: list[Attachment]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this Offer.

        List of offer attachments. You can attach up to 7 files to the offer – one per each attachment type as described in <a href=\"/documentation/#operation/createOfferAttachmentUsingPOST\" target=\"_blank\">uploading offer attachments flow</a>.  # noqa: E501

        :param attachments: The attachments of this Offer.  # noqa: E501
        :type: list[Attachment]
        """

        self._attachments = attachments

    @property
    def category(self):
        """Gets the category of this Offer.  # noqa: E501


        :return: The category of this Offer.  # noqa: E501
        :rtype: Category
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Offer.


        :param category: The category of this Offer.  # noqa: E501
        :type: Category
        """

        self._category = category

    @property
    def compatibility_list(self):
        """Gets the compatibility_list of this Offer.  # noqa: E501


        :return: The compatibility_list of this Offer.  # noqa: E501
        :rtype: CompatibilityList
        """
        return self._compatibility_list

    @compatibility_list.setter
    def compatibility_list(self, compatibility_list):
        """Sets the compatibility_list of this Offer.


        :param compatibility_list: The compatibility_list of this Offer.  # noqa: E501
        :type: CompatibilityList
        """

        self._compatibility_list = compatibility_list

    @property
    def contact(self):
        """Gets the contact of this Offer.  # noqa: E501


        :return: The contact of this Offer.  # noqa: E501
        :rtype: JustId
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """Sets the contact of this Offer.


        :param contact: The contact of this Offer.  # noqa: E501
        :type: JustId
        """

        self._contact = contact

    @property
    def created_at(self):
        """Gets the created_at of this Offer.  # noqa: E501

        Creation date: Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ. Cannot be modified.  # noqa: E501

        :return: The created_at of this Offer.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Offer.

        Creation date: Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ. Cannot be modified.  # noqa: E501

        :param created_at: The created_at of this Offer.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def delivery(self):
        """Gets the delivery of this Offer.  # noqa: E501


        :return: The delivery of this Offer.  # noqa: E501
        :rtype: Delivery
        """
        return self._delivery

    @delivery.setter
    def delivery(self, delivery):
        """Sets the delivery of this Offer.


        :param delivery: The delivery of this Offer.  # noqa: E501
        :type: Delivery
        """

        self._delivery = delivery

    @property
    def description(self):
        """Gets the description of this Offer.  # noqa: E501


        :return: The description of this Offer.  # noqa: E501
        :rtype: StandardizedDescription
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Offer.


        :param description: The description of this Offer.  # noqa: E501
        :type: StandardizedDescription
        """

        self._description = description

    @property
    def ean(self):
        """Gets the ean of this Offer.  # noqa: E501


        :return: The ean of this Offer.  # noqa: E501
        :rtype: str
        """
        return self._ean

    @ean.setter
    def ean(self, ean):
        """Sets the ean of this Offer.


        :param ean: The ean of this Offer.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                ean is not None and len(ean) > 18):
            raise ValueError("Invalid value for `ean`, length must be less than or equal to `18`")  # noqa: E501

        self._ean = ean

    @property
    def external(self):
        """Gets the external of this Offer.  # noqa: E501


        :return: The external of this Offer.  # noqa: E501
        :rtype: ExternalId
        """
        return self._external

    @external.setter
    def external(self, external):
        """Sets the external of this Offer.


        :param external: The external of this Offer.  # noqa: E501
        :type: ExternalId
        """

        self._external = external

    @property
    def id(self):
        """Gets the id of this Offer.  # noqa: E501


        :return: The id of this Offer.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Offer.


        :param id: The id of this Offer.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def images(self):
        """Gets the images of this Offer.  # noqa: E501


        :return: The images of this Offer.  # noqa: E501
        :rtype: list[ImageUrl]
        """
        return self._images

    @images.setter
    def images(self, images):
        """Sets the images of this Offer.


        :param images: The images of this Offer.  # noqa: E501
        :type: list[ImageUrl]
        """

        self._images = images

    @property
    def location(self):
        """Gets the location of this Offer.  # noqa: E501


        :return: The location of this Offer.  # noqa: E501
        :rtype: Location
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this Offer.


        :param location: The location of this Offer.  # noqa: E501
        :type: Location
        """

        self._location = location

    @property
    def name(self):
        """Gets the name of this Offer.  # noqa: E501

        Name of the offer. Words used in the name field cannot be longer than 30 characters.  # noqa: E501

        :return: The name of this Offer.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Offer.

        Name of the offer. Words used in the name field cannot be longer than 30 characters.  # noqa: E501

        :param name: The name of this Offer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 50):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `50`")  # noqa: E501

        self._name = name

    @property
    def parameters(self):
        """Gets the parameters of this Offer.  # noqa: E501


        :return: The parameters of this Offer.  # noqa: E501
        :rtype: list[Parameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this Offer.


        :param parameters: The parameters of this Offer.  # noqa: E501
        :type: list[Parameter]
        """

        self._parameters = parameters

    @property
    def payments(self):
        """Gets the payments of this Offer.  # noqa: E501


        :return: The payments of this Offer.  # noqa: E501
        :rtype: Payments
        """
        return self._payments

    @payments.setter
    def payments(self, payments):
        """Sets the payments of this Offer.


        :param payments: The payments of this Offer.  # noqa: E501
        :type: Payments
        """

        self._payments = payments

    @property
    def product(self):
        """Gets the product of this Offer.  # noqa: E501


        :return: The product of this Offer.  # noqa: E501
        :rtype: JustId
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this Offer.


        :param product: The product of this Offer.  # noqa: E501
        :type: JustId
        """

        self._product = product

    @property
    def promotion(self):
        """Gets the promotion of this Offer.  # noqa: E501


        :return: The promotion of this Offer.  # noqa: E501
        :rtype: Promotion
        """
        return self._promotion

    @promotion.setter
    def promotion(self, promotion):
        """Sets the promotion of this Offer.


        :param promotion: The promotion of this Offer.  # noqa: E501
        :type: Promotion
        """

        self._promotion = promotion

    @property
    def publication(self):
        """Gets the publication of this Offer.  # noqa: E501


        :return: The publication of this Offer.  # noqa: E501
        :rtype: Publication
        """
        return self._publication

    @publication.setter
    def publication(self, publication):
        """Sets the publication of this Offer.


        :param publication: The publication of this Offer.  # noqa: E501
        :type: Publication
        """

        self._publication = publication

    @property
    def selling_mode(self):
        """Gets the selling_mode of this Offer.  # noqa: E501


        :return: The selling_mode of this Offer.  # noqa: E501
        :rtype: SellingMode
        """
        return self._selling_mode

    @selling_mode.setter
    def selling_mode(self, selling_mode):
        """Sets the selling_mode of this Offer.


        :param selling_mode: The selling_mode of this Offer.  # noqa: E501
        :type: SellingMode
        """

        self._selling_mode = selling_mode

    @property
    def size_table(self):
        """Gets the size_table of this Offer.  # noqa: E501


        :return: The size_table of this Offer.  # noqa: E501
        :rtype: JustId
        """
        return self._size_table

    @size_table.setter
    def size_table(self, size_table):
        """Sets the size_table of this Offer.


        :param size_table: The size_table of this Offer.  # noqa: E501
        :type: JustId
        """

        self._size_table = size_table

    @property
    def stock(self):
        """Gets the stock of this Offer.  # noqa: E501


        :return: The stock of this Offer.  # noqa: E501
        :rtype: Stock
        """
        return self._stock

    @stock.setter
    def stock(self, stock):
        """Sets the stock of this Offer.


        :param stock: The stock of this Offer.  # noqa: E501
        :type: Stock
        """

        self._stock = stock

    @property
    def tecdoc_specification(self):
        """Gets the tecdoc_specification of this Offer.  # noqa: E501


        :return: The tecdoc_specification of this Offer.  # noqa: E501
        :rtype: TecdocSpecification
        """
        return self._tecdoc_specification

    @tecdoc_specification.setter
    def tecdoc_specification(self, tecdoc_specification):
        """Sets the tecdoc_specification of this Offer.


        :param tecdoc_specification: The tecdoc_specification of this Offer.  # noqa: E501
        :type: TecdocSpecification
        """

        self._tecdoc_specification = tecdoc_specification

    @property
    def updated_at(self):
        """Gets the updated_at of this Offer.  # noqa: E501

        Last update date: Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ. Cannot be modified  # noqa: E501

        :return: The updated_at of this Offer.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Offer.

        Last update date: Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ. Cannot be modified  # noqa: E501

        :param updated_at: The updated_at of this Offer.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def validation(self):
        """Gets the validation of this Offer.  # noqa: E501


        :return: The validation of this Offer.  # noqa: E501
        :rtype: Validation
        """
        return self._validation

    @validation.setter
    def validation(self, validation):
        """Sets the validation of this Offer.


        :param validation: The validation of this Offer.  # noqa: E501
        :type: Validation
        """

        self._validation = validation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Offer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Offer):
            return True

        return self.to_dict() != other.to_dict()
